@@ -6,4 +6,4 @@ cd "`dirname "$0"`"
 
 export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$(pwd)
 
-./doublecmd
\ No newline at end of file
+./doublecmd "$@"
