@@ -1,3 +1,6 @@
+#ifndef _COMMON_H
+#define _COMMON_H
+
 #ifdef __GNUC__
 
 #include <stdint.h>
@@ -5,11 +8,12 @@
 #if defined(__WIN32__) || defined(_WIN32) || defined(_WIN64)
   #define DCPCALL __attribute__((stdcall))
 #else
-  #define DCPCALL __attribute__((cdecl))
+  #define DCPCALL
 #endif
 
 #define MAX_PATH 260
 
+typedef int32_t LONG;
 typedef uint32_t DWORD;
 typedef uint16_t WORD;
 typedef void *HANDLE;
@@ -19,9 +23,18 @@ typedef HANDLE HWND;
 typedef int BOOL;
 typedef char CHAR;
 typedef uint16_t WCHAR;
+typedef intptr_t LPARAM;
+typedef uintptr_t WPARAM;
 
 #pragma pack(push, 1)
 
+typedef struct _RECT {
+  LONG left;
+  LONG top;
+  LONG right;
+  LONG bottom;
+} RECT, *PRECT;
+
 typedef struct _FILETIME {
 	DWORD dwLowDateTime;
 	DWORD dwHighDateTime;
@@ -63,4 +76,6 @@ typedef struct _WIN32_FIND_DATAW {
   #define DCPCALL __cdecl
 #endif
 
-#endif
\ No newline at end of file
+#endif
+
+#endif // _COMMON_H
